/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.cropcircle.view;

import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.util.ArrayList;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSlider;
import javax.swing.JTextField;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import nl.cloudfarming.client.sensor.cropcircle.CropcirclePreference;
import org.openide.util.NbBundle;

public class CropcircleMetadataPanel extends JPanel {

    private static final String GAP_RIGHT = "gapright 450";
    private javax.swing.JLabel channelLabel1;
    private javax.swing.JLabel channelLabel2;
    private javax.swing.JLabel channelLabel3;
    private javax.swing.JTextField channelTextField1;
    private javax.swing.JTextField channelTextField2;
    private javax.swing.JTextField channelTextField3;
    private javax.swing.JSlider cropCircleSensorHeightSlider;
    private javax.swing.JLabel cropCircleSensorHeightDisplayLabel;
    private javax.swing.JLabel cropcircleLabel;
    private javax.swing.JLabel cropcircleSensorHeightLabel;
    private javax.swing.JComboBox dateFormatComboBox;
    private javax.swing.JLabel fileFormatLabel;
    private javax.swing.JLabel spectralHintLabel;
    private javax.swing.JLabel spectralValueDescription;
    private javax.swing.JLabel meterLabel;
    private javax.swing.JComboBox numberOfSensorCombobox;
    private javax.swing.JLabel numberOfSensorLabel;
    private javax.swing.JComboBox sensorTypeComboBox;
    private javax.swing.JLabel sensorTypeLabel;
    private SensorSpreadController sensorSpreadController = new SensorSpreadController();

    CropcircleMetadataPanel() {
        initComponents();
    }

    /** This method is called from within the constructor to
     * initialize the form.
     */
    private void initComponents() {

        fileFormatLabel = new javax.swing.JLabel();
        cropcircleSensorHeightLabel = new javax.swing.JLabel();
        meterLabel = new javax.swing.JLabel();
        sensorSpreadController = new SensorSpreadController();
        cropcircleLabel = new javax.swing.JLabel();
        cropCircleSensorHeightSlider = new javax.swing.JSlider();
        cropCircleSensorHeightDisplayLabel = new javax.swing.JLabel();
        numberOfSensorCombobox = new javax.swing.JComboBox();
        numberOfSensorLabel = new javax.swing.JLabel();
        dateFormatComboBox = new javax.swing.JComboBox();

        sensorTypeLabel = new javax.swing.JLabel();
        sensorTypeComboBox = new javax.swing.JComboBox();
        spectralHintLabel = new javax.swing.JLabel();
        channelLabel1 = new javax.swing.JLabel();
        channelLabel2 = new javax.swing.JLabel();
        channelLabel3 = new javax.swing.JLabel();
        spectralValueDescription = new javax.swing.JLabel();
        channelTextField1 = new javax.swing.JTextField();
        channelTextField2 = new javax.swing.JTextField();
        channelTextField3 = new javax.swing.JTextField();

        fileFormatLabel.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.fileFormatLabel.text"));
        fileFormatLabel.setToolTipText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.fileFormatLabel.toolTipText"));

        cropcircleSensorHeightLabel.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropcircleSensorHeightLabel.text"));
        cropcircleSensorHeightLabel.setToolTipText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropcircleSensorHeightLabel.toolTipText"));

        meterLabel.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.meterLabel.text"));

        cropcircleLabel.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropcircleLabel.text"));

        cropCircleSensorHeightSlider.setMaximum(500);
        cropCircleSensorHeightSlider.setToolTipText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorHeightSlider.toolTipText"));
        cropCircleSensorHeightSlider.setValue(0);
        cropCircleSensorHeightSlider.setMaximumSize(new java.awt.Dimension(32767, 14));
        cropCircleSensorHeightSlider.setMinimumSize(new java.awt.Dimension(36, 14));
        cropCircleSensorHeightSlider.setPreferredSize(new java.awt.Dimension(200, 14));

        cropCircleSensorHeightDisplayLabel.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorHieghtDisplayLabel.text"));
        cropCircleSensorHeightDisplayLabel.setToolTipText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorHieghtDisplayLabel.toolTipText")); // NOI18N

        numberOfSensorCombobox.setModel(new javax.swing.DefaultComboBoxModel(new String[]{"2", "4", "6"}));
        numberOfSensorCombobox.setToolTipText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.numberOfSensorCombobox.toolTipText")); // NOI18N


        numberOfSensorLabel.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.numberOfSensorLabel.text"));
        numberOfSensorLabel.setToolTipText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.numberOfSensorLabel.toolTipText")); // NOI18N

        dateFormatComboBox.setModel(new javax.swing.DefaultComboBoxModel(new String[]{"DDMMYY", "YYYYMMDD"}));

        sensorTypeLabel.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.sensorTypeLabel.text"));

        sensorTypeComboBox.setModel(new javax.swing.DefaultComboBoxModel(new String[]{"ACS-430", "ACS-470"}));
        spectralHintLabel.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.spectralHintLabel.text"));

        channelLabel1.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.channelLabel1.text"));
        channelLabel2.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.channelLabel2.text"));
        channelLabel3.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.Channel3Label.text"));

        spectralValueDescription.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.spectralValueDescription.text"));

        channelTextField1.setText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.channelTextField1.text"));
        channelTextField1.setPreferredSize(new java.awt.Dimension(60, 20));

        channelTextField2.setText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.channelTextField2.text"));
        channelTextField2.setPreferredSize(new java.awt.Dimension(60, 20));

        channelTextField3.setText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.channelTextField3.text"));
        channelTextField3.setPreferredSize(new java.awt.Dimension(60, 20));

        MigLayout layout = new MigLayout("wrap 4");
        this.setLayout(layout);
        this.add(cropcircleLabel, GAP_RIGHT);
        this.add(dateFormatComboBox, "right, wrap");
        this.add(cropcircleSensorHeightLabel, GAP_RIGHT);
        this.add(cropCircleSensorHeightSlider);
        this.add(cropCircleSensorHeightDisplayLabel);
        this.add(meterLabel);
        this.add(numberOfSensorLabel, GAP_RIGHT);
        this.add(numberOfSensorCombobox, "right, wrap");
        this.add(sensorSpreadController.getComponent(), "span 4");

        this.add(sensorTypeLabel);
        this.add(sensorTypeComboBox, "right, wrap");
        this.add(spectralHintLabel, "span 4");
        this.add(channelLabel1);
        this.add(channelTextField1, "right, wrap");
        this.add(channelLabel2);
        this.add(channelTextField2, "right, wrap");
        this.add(channelLabel3);
        this.add(channelTextField3, "right, wrap");
        this.add(spectralValueDescription, "span 4");
    }

    public JSlider getCropCircleSensorHeightSlider() {
        return cropCircleSensorHeightSlider;
    }

    public JLabel getCropCircleSensorHeightDisplayLabel() {
        return cropCircleSensorHeightDisplayLabel;
    }

    public JComboBox getNumberOfSensorCombobox() {
        return numberOfSensorCombobox;
    }

    public SensorSpreadController getSensorSpreadController() {
        return sensorSpreadController;
    }

    public JComboBox getDateFormatComboBox() {
        return dateFormatComboBox;
    }

    public JComboBox getSensorTypeComboBox() {
        return sensorTypeComboBox;
    }

    public JTextField getChannelTextField1() {
        return channelTextField1;
    }

    public JTextField getChannelTextField2() {
        return channelTextField2;
    }

    public JTextField getChannelTextField3() {
        return channelTextField3;
    }

    /**
     * SensorSpread panel. Responsible for displaying the sensorSpread components
     */
    public class SensorSpread extends JPanel {

        private javax.swing.JLabel desriptionText;
        private javax.swing.JLabel senSorSpreadHintLabel;
        private javax.swing.JLabel leftLabel;
        private javax.swing.JLabel rightLabel;
        private javax.swing.JLabel cropCircleSensorSpreadLabelL1;
        private javax.swing.JLabel cropCircleSensorSpreadLabelL2;
        private javax.swing.JLabel cropCircleSensorSpreadLabelL3;
        private javax.swing.JLabel cropCircleSensorSpreadLabelR1;
        private javax.swing.JLabel cropCircleSensorSpreadLabelR2;
        private javax.swing.JLabel cropCircleSensorSpreadLabelR3;
        private javax.swing.JTextField cropCircleSensorSpreadTextFieldL1;
        private javax.swing.JTextField cropCircleSensorSpreadTextFieldL2;
        private javax.swing.JTextField cropCircleSensorSpreadTextFieldL3;
        private javax.swing.JTextField cropCircleSensorSpreadTextFieldR1;
        private javax.swing.JTextField cropCircleSensorSpreadTextFieldR2;
        private javax.swing.JTextField cropCircleSensorSpreadTextFieldR3;
        private javax.swing.JLabel cropCircleSenosorSpreadCentimeterLabel;
        private final String SENSOR_SPREAD_DESCRIPTION_TEXT = NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.descriptionText.text");
        private final String SENSOR_SPREAD_HINT_TEXT = NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.sensor_spread_hint_text.text");
        private final String SENSOR_SPREAD_LABELLabel_L1_TEXT = NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadLabelL1.text");
        private final String SENSOR_SPREAD_LABELLabel_L2_TEXT = NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadLabelL2.text");
        private final String SENSOR_SPREAD_LABELLabel_L3_TEXT = NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadLabelL3.text");
        private final String SENSOR_SPREAD_LABELLabel_R1_TEXT = NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadLabelR1.text");
        private final String SENSOR_SPREAD_LABELLabel_R2_TEXT = NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadLabelR2.text");
        private final String SENSOR_SPREAD_LABELLabel_R3_TEXT = NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadLabelR3.text");
        private final String LEFT_LABEL = NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.left_label.text");
        private final String RIGHT_LABEL = NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.right_label.text");
        private final String CENTIMETER_LABEL = NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSenosorSpreadCentimeterLabel.text");
        private JPanel sensorSpreadPanel;
        private JPanel leftPanel;
        private JPanel rightPanel;
        private static final int CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_WIDHT = 59;
        private static final int CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_HEIGHT = 20;

        public SensorSpread() {
            initComponents();
        }

        private void initComponents() {
            sensorSpreadPanel = new JPanel();
            sensorSpreadPanel.setLayout(new MigLayout("wrap 2"));
            leftPanel = new JPanel();
            leftPanel.setLayout(new MigLayout("wrap 3"));
            rightPanel = new JPanel();
            rightPanel.setLayout(new MigLayout("wrap 3"));

            desriptionText = new javax.swing.JLabel();
            desriptionText.setText(SENSOR_SPREAD_DESCRIPTION_TEXT);
            senSorSpreadHintLabel = new javax.swing.JLabel();
            senSorSpreadHintLabel.setText(SENSOR_SPREAD_HINT_TEXT);


            leftLabel = new javax.swing.JLabel(LEFT_LABEL);
            rightLabel = new javax.swing.JLabel(RIGHT_LABEL);

            cropCircleSensorSpreadTextFieldL1 = new javax.swing.JTextField();
            cropCircleSensorSpreadTextFieldR1 = new javax.swing.JTextField();
            cropCircleSensorSpreadTextFieldL2 = new javax.swing.JTextField();
            cropCircleSensorSpreadTextFieldR2 = new javax.swing.JTextField();
            cropCircleSensorSpreadTextFieldR3 = new javax.swing.JTextField();
            cropCircleSensorSpreadTextFieldL3 = new javax.swing.JTextField();

            cropCircleSensorSpreadLabelL1 = new javax.swing.JLabel();
            cropCircleSensorSpreadLabelL2 = new javax.swing.JLabel();
            cropCircleSensorSpreadLabelL3 = new javax.swing.JLabel();
            cropCircleSensorSpreadLabelR1 = new javax.swing.JLabel();
            cropCircleSensorSpreadLabelR2 = new javax.swing.JLabel();
            cropCircleSensorSpreadLabelR3 = new javax.swing.JLabel();

            cropCircleSensorSpreadLabelL1.setText(SENSOR_SPREAD_LABELLabel_L1_TEXT);
            cropCircleSensorSpreadLabelL2.setText(SENSOR_SPREAD_LABELLabel_L2_TEXT);
            cropCircleSensorSpreadLabelL3.setText(SENSOR_SPREAD_LABELLabel_L3_TEXT);
            cropCircleSensorSpreadLabelR1.setText(SENSOR_SPREAD_LABELLabel_R1_TEXT);
            cropCircleSensorSpreadLabelR2.setText(SENSOR_SPREAD_LABELLabel_R2_TEXT);
            cropCircleSensorSpreadLabelR3.setText(SENSOR_SPREAD_LABELLabel_R3_TEXT);

            cropCircleSenosorSpreadCentimeterLabel = new javax.swing.JLabel(CENTIMETER_LABEL);

            this.setLayout(new MigLayout("wrap 2"));

            cropCircleSensorSpreadTextFieldL1.setText(NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadTextFieldL1.text")); // NOI18N
            cropCircleSensorSpreadTextFieldL1.setPreferredSize(new java.awt.Dimension(CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_WIDHT, CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_HEIGHT));
            cropCircleSensorSpreadTextFieldL2.setText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadTextFieldL2.text")); // NOI18N
            cropCircleSensorSpreadTextFieldL2.setPreferredSize(new java.awt.Dimension(CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_WIDHT, CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_HEIGHT));
            cropCircleSensorSpreadTextFieldL3.setText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadTextFieldL3.text")); // NOI18N
            cropCircleSensorSpreadTextFieldL3.setPreferredSize(new java.awt.Dimension(CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_WIDHT, CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_HEIGHT));
            cropCircleSensorSpreadTextFieldR1.setText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadTextFieldR1.text")); // NOI18N
            cropCircleSensorSpreadTextFieldR1.setPreferredSize(new java.awt.Dimension(CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_WIDHT, CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_HEIGHT));
            cropCircleSensorSpreadTextFieldR2.setText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadTextFieldR2.text")); // NOI18N
            cropCircleSensorSpreadTextFieldR2.setPreferredSize(new java.awt.Dimension(CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_WIDHT, CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_HEIGHT));
            cropCircleSensorSpreadTextFieldR3.setText(org.openide.util.NbBundle.getMessage(CropcircleMetadataController.class, "CropcircleMetadataPanel.cropCircleSensorSpreadTextFieldR3.text")); // NOI18N
            cropCircleSensorSpreadTextFieldR3.setPreferredSize(new java.awt.Dimension(CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_WIDHT, CROP_CIRCLE_SENSOR_SPREAD_TEXTFIELD_HEIGHT));

            this.add(desriptionText, "span 2");
            this.add(senSorSpreadHintLabel, "span 2");
            leftPanel.add(leftLabel, "right, span 3");
            leftPanel.add(cropCircleSensorSpreadLabelL3);
            leftPanel.add(cropCircleSensorSpreadLabelL2);
            leftPanel.add(cropCircleSensorSpreadLabelL1);
            leftPanel.add(cropCircleSensorSpreadTextFieldL3);
            leftPanel.add(cropCircleSensorSpreadTextFieldL2);
            leftPanel.add(cropCircleSensorSpreadTextFieldL1);


            rightPanel.add(rightLabel, "span 3");
            rightPanel.add(cropCircleSensorSpreadLabelR1);
            rightPanel.add(cropCircleSensorSpreadLabelR2);
            rightPanel.add(cropCircleSensorSpreadLabelR3);
            rightPanel.add(cropCircleSensorSpreadTextFieldR1);
            rightPanel.add(cropCircleSensorSpreadTextFieldR2);
            rightPanel.add(cropCircleSensorSpreadTextFieldR3);


            sensorSpreadPanel.add(leftPanel);
            sensorSpreadPanel.add(rightPanel);
            this.add(sensorSpreadPanel, "span 2, right");
            this.add(cropCircleSenosorSpreadCentimeterLabel, "span 2, right");
        }

        public JTextField getCropCircleSensorSpreadTextFieldL1() {
            return cropCircleSensorSpreadTextFieldL1;
        }

        public JTextField getCropCircleSensorSpreadTextFieldL2() {
            return cropCircleSensorSpreadTextFieldL2;
        }

        public JTextField getCropCircleSensorSpreadTextFieldL3() {
            return cropCircleSensorSpreadTextFieldL3;
        }

        public JTextField getCropCircleSensorSpreadTextFieldR1() {
            return cropCircleSensorSpreadTextFieldR1;
        }

        public JTextField getCropCircleSensorSpreadTextFieldR2() {
            return cropCircleSensorSpreadTextFieldR2;
        }

        public JTextField getCropCircleSensorSpreadTextFieldR3() {
            return cropCircleSensorSpreadTextFieldR3;
        }

        public String getCropCircleSensorSpread() {
            ArrayList<javax.swing.JTextField> fields = new ArrayList<javax.swing.JTextField>();
            fields.add(cropCircleSensorSpreadTextFieldL3);
            fields.add(cropCircleSensorSpreadTextFieldL2);
            fields.add(cropCircleSensorSpreadTextFieldL1);
            fields.add(cropCircleSensorSpreadTextFieldR1);
            fields.add(cropCircleSensorSpreadTextFieldR2);
            fields.add(cropCircleSensorSpreadTextFieldR3);
            StringBuilder cropCircleSpread = new StringBuilder();
            for (javax.swing.JTextField textField : fields) {
                if (textField.isEnabled()) {
                    cropCircleSpread.append(textField.getText());
                    cropCircleSpread.append(",");
                }

            }
            //Delete last ','
            cropCircleSpread.deleteCharAt(cropCircleSpread.length() - 1);
            return cropCircleSpread.toString();
        }
    }

    /**
     * Controller for the sensorSpread panel
     */
    public class SensorSpreadController implements KeyListener {

        private SensorSpread sensorSpread;
        private final AppLogger LOG = AppLogFactory.getLogger(CropcircleMetadataController.class);

        public SensorSpreadController() {
            init();
        }

        public void init() {
            getComponent().getCropCircleSensorSpreadTextFieldL1().addKeyListener(this);
            getComponent().getCropCircleSensorSpreadTextFieldL2().addKeyListener(this);
            getComponent().getCropCircleSensorSpreadTextFieldR1().addKeyListener(this);
            getComponent().getCropCircleSensorSpreadTextFieldR2().addKeyListener(this);
        }

        public  SensorSpread getComponent() {
            if (sensorSpread == null) {
                sensorSpread = new SensorSpread();
            }
            return sensorSpread;
        }

        public void load() {
            setCropCircleSensorSpread(CropcirclePreference.CROPCIRCLE_SENSOR_SPREAD.getValue());
        }

        public void store() {
            CropcirclePreference.CROPCIRCLE_SENSOR_SPREAD.saveValue(getComponent().getCropCircleSensorSpread());
        }
        
        boolean valid() {
            ArrayList<javax.swing.JTextField> fields = new ArrayList<javax.swing.JTextField>();
            fields.add(getComponent().getCropCircleSensorSpreadTextFieldL3());
            fields.add(getComponent().getCropCircleSensorSpreadTextFieldL2());
            fields.add(getComponent().getCropCircleSensorSpreadTextFieldL1());
            fields.add(getComponent().getCropCircleSensorSpreadTextFieldR1());
            fields.add(getComponent().getCropCircleSensorSpreadTextFieldR2());
            fields.add(getComponent().getCropCircleSensorSpreadTextFieldR3());
            for (javax.swing.JTextField textField : fields) {
                if (textField.isEnabled()) {
                    if (!textField.getText().matches("[0-9]*")) {
                        return false;
                    }
                }
            }
            return true;
        }

        public void displaySensorSpreadComponents(int number) {
            switch (number) {
                case 2:
                    getComponent().getCropCircleSensorSpreadTextFieldL2().setEnabled(false);
                    getComponent().getCropCircleSensorSpreadTextFieldR2().setEnabled(false);
                    getComponent().getCropCircleSensorSpreadTextFieldL3().setEnabled(false);
                    getComponent().getCropCircleSensorSpreadTextFieldR3().setEnabled(false);
                    break;
                case 4:
                    getComponent().getCropCircleSensorSpreadTextFieldL2().setEnabled(true);
                    getComponent().getCropCircleSensorSpreadTextFieldR2().setEnabled(true);
                    getComponent().getCropCircleSensorSpreadTextFieldL3().setEnabled(false);
                    getComponent().getCropCircleSensorSpreadTextFieldR3().setEnabled(false);
                    break;
                case 6:
                    getComponent().getCropCircleSensorSpreadTextFieldL2().setEnabled(true);
                    getComponent().getCropCircleSensorSpreadTextFieldR2().setEnabled(true);
                    getComponent().getCropCircleSensorSpreadTextFieldL3().setEnabled(true);
                    getComponent().getCropCircleSensorSpreadTextFieldR3().setEnabled(true);
                    break;
                default:
                    getComponent().getCropCircleSensorSpreadTextFieldL1().setEnabled(true);
                    getComponent().getCropCircleSensorSpreadTextFieldR1().setEnabled(true);
                    getComponent().getCropCircleSensorSpreadTextFieldL2().setEnabled(false);
                    getComponent().getCropCircleSensorSpreadTextFieldR2().setEnabled(false);
                    getComponent().getCropCircleSensorSpreadTextFieldL3().setEnabled(false);
                    getComponent().getCropCircleSensorSpreadTextFieldR3().setEnabled(false);
                    break;
            }
        }

        public void setCropCircleSensorSpread(String cropCircleSpread) {
            int savedNumber = Integer.parseInt(CropcirclePreference.NUMBER_OF_CROPCIRCLE_SENSORS.getValue());
            String[] spreadNumber = cropCircleSpread.split(",");
            int numberInString = spreadNumber.length;
            if (savedNumber != numberInString && numberInString != 0) {
                //Something went wrong restore defaults and log
                StringBuilder logBuilder = new StringBuilder("Could not load sensor spread expected: ");
                logBuilder.append(savedNumber);
                logBuilder.append("but receaved saved string: ");
                logBuilder.append(cropCircleSpread);
                LOG.error(logBuilder.toString());
            } else {
                if (numberInString == 2) {
                    getComponent().getCropCircleSensorSpreadTextFieldL1().setText(spreadNumber[0]);
                    getComponent().getCropCircleSensorSpreadTextFieldR1().setText(spreadNumber[1]);
                } else if (numberInString == 4) {
                    getComponent().getCropCircleSensorSpreadTextFieldL2().setText(spreadNumber[0]);
                    getComponent().getCropCircleSensorSpreadTextFieldL1().setText(spreadNumber[1]);
                    getComponent().getCropCircleSensorSpreadTextFieldR1().setText(spreadNumber[2]);
                    getComponent().getCropCircleSensorSpreadTextFieldR2().setText(spreadNumber[3]);
                } else if (numberInString == 6) {
                    getComponent().getCropCircleSensorSpreadTextFieldL3().setText(spreadNumber[0]);
                    getComponent().getCropCircleSensorSpreadTextFieldL2().setText(spreadNumber[1]);
                    getComponent().getCropCircleSensorSpreadTextFieldL1().setText(spreadNumber[2]);
                    getComponent().getCropCircleSensorSpreadTextFieldR1().setText(spreadNumber[3]);
                    getComponent().getCropCircleSensorSpreadTextFieldR2().setText(spreadNumber[4]);
                    getComponent().getCropCircleSensorSpreadTextFieldR3().setText(spreadNumber[5]);
                }
            }
        }

        @Override
        public void keyTyped(KeyEvent e) {
            //Do nothing
        }

        @Override
        public void keyPressed(KeyEvent e) {
            //Do nothing
        }

        @Override
        public void keyReleased(KeyEvent e) {
            if (e.getSource() == getComponent().getCropCircleSensorSpreadTextFieldL1()) {
                getComponent().getCropCircleSensorSpreadTextFieldL2().setText(getComponent().getCropCircleSensorSpreadTextFieldL1().getText());
            } else if (e.getSource() == getComponent().getCropCircleSensorSpreadTextFieldL2()) {
                getComponent().getCropCircleSensorSpreadTextFieldL3().setText(getComponent().getCropCircleSensorSpreadTextFieldL2().getText());
            } else if (e.getSource() == getComponent().getCropCircleSensorSpreadTextFieldR1()) {
                getComponent().getCropCircleSensorSpreadTextFieldR2().setText(getComponent().getCropCircleSensorSpreadTextFieldR1().getText());
            } else if (e.getSource() == getComponent().getCropCircleSensorSpreadTextFieldR2()) {
                getComponent().getCropCircleSensorSpreadTextFieldR3().setText(getComponent().getCropCircleSensorSpreadTextFieldR2().getText());
            }
        }
    }
}
